Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(503)

Unified Diff: chrome/browser/ui/cocoa/website_settings/permission_bubble_controller.h

Issue 1905273002: Fix positioning of Mac permission prompts when fullscreen. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Feedback Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/website_settings/permission_bubble_controller.h
diff --git a/chrome/browser/ui/cocoa/website_settings/permission_bubble_controller.h b/chrome/browser/ui/cocoa/website_settings/permission_bubble_controller.h
index 8d57f854af9cf6da995569dbb65a67f609590655..483db63c0c67d24412ed2f0022b36c0266e09753 100644
--- a/chrome/browser/ui/cocoa/website_settings/permission_bubble_controller.h
+++ b/chrome/browser/ui/cocoa/website_settings/permission_bubble_controller.h
@@ -49,8 +49,8 @@ class PermissionBubbleRequest;
// Should only be used outside this class for tests.
- (NSPoint)getExpectedAnchorPoint;
-// Returns true of the browser has support for the location bar.
+// Returns true if the browser has a visible location bar.
// Should only be used outside this class for tests.
-- (bool)hasLocationBar;
+- (bool)hasVisibleLocationBar;
@end

Powered by Google App Engine
This is Rietveld 408576698